==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/gamekit/GKChallengeEventHandlerDelegate.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.gamekit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 6.0 and later.
 * @deprecated Deprecated in iOS 7.0.
 */
@Deprecated
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ interface /*<name>*/GKChallengeEventHandlerDelegate/*</name>*/ 
    /*<implements>*/extends NSObjectProtocol/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<methods>*/
    @Method(selector = "localPlayerDidSelectChallenge:")
    void localPlayerDidSelectChallenge(GKChallenge challenge);
    @Method(selector = "shouldShowBannerForLocallyReceivedChallenge:")
    boolean shouldShowBannerForLocallyReceivedChallenge(GKChallenge challenge);
    @Method(selector = "localPlayerDidReceiveChallenge:")
    void localPlayerDidReceiveChallenge(GKChallenge challenge);
    @Method(selector = "shouldShowBannerForLocallyCompletedChallenge:")
    boolean shouldShowBannerForLocallyCompletedChallenge(GKChallenge challenge);
    @Method(selector = "localPlayerDidCompleteChallenge:")
    void localPlayerDidCompleteChallenge(GKChallenge challenge);
    @Method(selector = "shouldShowBannerForRemotelyCompletedChallenge:")
    boolean shouldShowBannerForRemotelyCompletedChallenge(GKChallenge challenge);
    @Method(selector = "remotePlayerDidCompleteChallenge:")
    void remotePlayerDidCompleteChallenge(GKChallenge challenge);
    /*</methods>*/
    /*<adapter>*/
    /*</adapter>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/gamekit/GKChallengeEventHandlerDelegate.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.gamekit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coregraphics.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @deprecated Deprecated in iOS 7.0. You should instead implement the GKChallengeListener protocol and register a listener with GKLocalPlayer.
 */
/*</javadoc>*/
/*<annotations>*/@Deprecated/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ interface /*<name>*/GKChallengeEventHandlerDelegate/*</name>*/ 
    /*<implements>*/extends NSObjectProtocol/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<methods>*/
    @Method(selector = "localPlayerDidSelectChallenge:")
    void localPlayerDidSelectChallenge(GKChallenge challenge);
    @Method(selector = "shouldShowBannerForLocallyReceivedChallenge:")
    boolean shouldShowBannerForLocallyReceivedChallenge(GKChallenge challenge);
    @Method(selector = "localPlayerDidReceiveChallenge:")
    void localPlayerDidReceiveChallenge(GKChallenge challenge);
    @Method(selector = "shouldShowBannerForLocallyCompletedChallenge:")
    boolean shouldShowBannerForLocallyCompletedChallenge(GKChallenge challenge);
    @Method(selector = "localPlayerDidCompleteChallenge:")
    void localPlayerDidCompleteChallenge(GKChallenge challenge);
    @Method(selector = "shouldShowBannerForRemotelyCompletedChallenge:")
    boolean shouldShowBannerForRemotelyCompletedChallenge(GKChallenge challenge);
    @Method(selector = "remotePlayerDidCompleteChallenge:")
    void remotePlayerDidCompleteChallenge(GKChallenge challenge);
    /*</methods>*/
    /*<adapter>*/
    /*</adapter>*/
}
